Money.Input.NoNumberSymbolsError exception (Money.Input v0.1.0)

Raised when a locale's number-symbol data can't be loaded.

This is normally only seen when CLDR data is incomplete for an exotic locale or when runtime locale download is disabled for a locale that wasn't pre-compiled into the build.